@@ -53,9 +53,31 @@
 #include "literal.h"
 #include "convert.h"
 
+/*
+ * ensure GTAGSLIBPATH compares correctly
+ */
+#if defined(_WIN32) || defined(__DJGPP__)
+#define STRCMP stricmp
+#define back2slash(sb) do {		\
+	char *p = strbuf_value(sb);	\
+	for (; *p; p++) 		\
+		if (*p == '\\')         \
+			*p = '/';       \
+} while (0)
+#else
+#define STRCMP strcmp
+#define back2slash(sb)
+#endif
+
+/*
+ * enable [set] globbing, if available
+ */
+#ifdef __CRT_GLOB_BRACKET_GROUPS__
+int _CRT_glob = __CRT_GLOB_USE_MINGW__ | __CRT_GLOB_BRACKET_GROUPS__;
+#endif
+
 /**
- * @file global.c
- * @NAME{global} - print locations of the specified object.
+ * global - print locations of the specified object.
  */
 static void usage(void);
 static void help(void);
@@ -107,7 +129,7 @@ int nofilter;
 int nosource;				/**< undocumented command */
 int debug;
 int literal;				/**< 1: literal search	*/
-int print0;				/**< @OPTION{-print0} option	*/
+int print0;				/**< --print0 option	*/
 int format;
 int type;				/**< path conversion type */
 int match_part;				/**< match part only	*/
@@ -125,13 +147,11 @@ char *encode_chars;
 char *single_update;
 char *path_style;
 
-/**
- * @name Path filter
+/*
+ * Path filter
  */
-/** @{ */
 int do_path;
 int convert_type = PATH_RELATIVE;
-/** @} */
 
 static void
 usage(void)
@@ -232,22 +252,20 @@ setcom(int c)
 		usage();
 }
 /**
- * @fn int decide_tag_by_context(const char *tag, const char *file, int lineno)
- *
  * decide_tag_by_context: decide tag type by context
  *
  *	@param[in]	tag	tag name
  *	@param[in]	file	context file
  *	@param[in]	lineno	context lineno
- *	@return		#GTAGS, #GRTAGS, #GSYMS
+ *	@return		GTAGS, GRTAGS, GSYMS
  */
+int
+decide_tag_by_context(const char *tag, const char *file, int lineno)
+{
 #define NEXT_NUMBER(p) do {                                                         \
 	for (n = 0; isdigit(*p); p++)                                               \
 		n = n * 10 + (*p - '0');                                            \
 } while (0)
-int
-decide_tag_by_context(const char *tag, const char *file, int lineno)
-{
 	STRBUF *sb = NULL;
 	char path[MAXPATHLEN], s_fid[MAXFIDLEN];
 	const char *tagline, *p;
@@ -339,12 +357,13 @@ finish:
 
 		sb = strbuf_open(0);
 		strbuf_puts(sb, getenv("GTAGSLIBPATH"));
+		back2slash(sb);
 		for (libdir = strbuf_value(sb); libdir; libdir = nextp) {
 			 if ((nextp = locatestring(libdir, PATHSEP, MATCH_FIRST)) != NULL)
                                 *nextp++ = 0;
 			if (!gtagsexist(libdir, libdbpath, sizeof(libdbpath), 0))
 				continue;
-			if (!strcmp(dbpath, libdbpath))
+			if (!STRCMP(dbpath, libdbpath))
 				continue;
 			dbop = dbop_open(makepath(libdbpath, dbname(GTAGS), NULL), 0, 0, 0);
 			if (dbop == NULL)
@@ -537,10 +556,10 @@ main(int argc, char **argv)
 			while (*p && isdigit(*p))
 				p++;
 			if (*p != ':')
-				die_with_code(2, usage);
+				die_with_code(2, "%s", usage);
 			*p++ = '\0';
 			if (!*p)
-				die_with_code(2, usage);
+				die_with_code(2, "%s", usage);
 			context_file = p;
 			}
 			break;
@@ -605,7 +624,7 @@ main(int argc, char **argv)
 	if (show_help)
 		help();
 	if (dbpath == NULL)
-		die_with_code(-status, gtags_dbpath_error);
+		die_with_code(-status, "%s", gtags_dbpath_error);
 	if (nearbase) {
 		if (!test("d", nearbase)) 
 			die("'%s' not found.", nearbase);
@@ -944,12 +963,12 @@ main(int argc, char **argv)
 	return 0;
 }
 /**
- * completion_tags: print completion list of specified @a prefix
+ * completion_tags: print completion list of specified prefix
  *
  *	@param[in]	dbpath	dbpath directory
  *	@param[in]	root	root directory
  *	@param[in]	prefix	prefix of primary key
- *	@param[in]	db	#GTAGS,#GRTAGS,#GSYMS
+ *	@param[in]	db	GTAGS,GRTAGS,GSYMS
  *	@return		number of words
  */
 int
@@ -973,12 +992,12 @@ completion_tags(const char *dbpath, const char *root, const char *prefix, int db
 	return count;
 }
 /**
- * completion: print completion list of specified @a prefix
+ * completion: print completion list of specified prefix
  *
  *	@param[in]	dbpath	dbpath directory
  *	@param[in]	root	root directory
  *	@param[in]	prefix	prefix of primary key
- *	@param[in]	db	#GTAGS,#GRTAGS,#GSYMS
+ *	@param[in]	db	GTAGS,GRTAGS,GSYMS
  */
 void
 completion(const char *dbpath, const char *root, const char *prefix, int db)
@@ -997,15 +1016,16 @@ completion(const char *dbpath, const char *root, const char *prefix, int db)
 		char *libdir, *nextp = NULL;
 
 		strbuf_puts(sb, getenv("GTAGSLIBPATH"));
+		back2slash(sb);
 		/*
-		* search for each tree in the library path.
-		*/
+		 * search for each tree in the library path.
+		 */
 		for (libdir = strbuf_value(sb); libdir; libdir = nextp) {
 			if ((nextp = locatestring(libdir, PATHSEP, MATCH_FIRST)) != NULL)
 				*nextp++ = 0;
 			if (!gtagsexist(libdir, libdbpath, sizeof(libdbpath), 0))
 				continue;
-			if (!strcmp(dbpath, libdbpath))
+			if (!STRCMP(dbpath, libdbpath))
 				continue;
 			if (!test("f", makepath(libdbpath, dbname(db), NULL)))
 				continue;
@@ -1022,7 +1042,7 @@ completion(const char *dbpath, const char *root, const char *prefix, int db)
 	/* return total; */
 }
 /**
- * completion_idutils: print completion list of specified @a prefix
+ * completion_idutils: print completion list of specified prefix
  *
  *	@param[in]	dbpath	dbpath directory
  *	@param[in]	root	root directory
@@ -1164,7 +1184,7 @@ completion_path(const char *dbpath, const char *prefix)
 /**
  * print number of object.
  *
- * This procedure is commonly used except for the @OPTION{-P} option.
+ * This procedure is commonly used except for the -P option.
  */
 void
 print_count(int number)
@@ -1184,10 +1204,10 @@ print_count(int number)
 	}
 }
 /**
- * idutils:  @NAME{lid}(@NAME{idutils}) pattern
+ * idutils:  lid(idutils) pattern
  *
- *	@param[in]	pattern	@NAME{POSIX} regular expression
- *	@param[in]	dbpath	@FILE{GTAGS} directory
+ *	@param[in]	pattern	POSIX regular expression
+ *	@param[in]	dbpath	"GTAGS" directory
  */
 void
 idutils(const char *pattern, const char *dbpath)
@@ -1291,9 +1311,9 @@ idutils(const char *pattern, const char *dbpath)
 	}
 }
 /**
- * grep: @NAME{grep} pattern
+ * grep: grep pattern
  *
- *	@param[in]	pattern	@NAME{POSIX} regular expression
+ *	@param[in]	pattern	POSIX regular expression
  *	@param	argv
  *	@param	dbpath
  */
@@ -1506,7 +1526,7 @@ pathlist(const char *pattern, const char *dbpath)
 	}
 }
 /**
- * @fn void parsefile(char *const *argv, const char *cwd, const char *root, const char *dbpath, int db)
+ * void parsefile(char *const *argv, const char *cwd, const char *root, const char *dbpath, int db)
  *
  * parsefile: parse file to pick up tags.
  *
@@ -1597,6 +1617,8 @@ parsefile(char *const *argv, const char *cwd, const char *root, const char *dbpa
 	if (wflag)
 		flags |= PARSER_WARNING;
 	*/
+	if (getenv("GTAGSFORCEENDBLOCK"))
+		flags |= PARSER_END_BLOCK;
 	if (db == GRTAGS + GSYMS)
 		data.target = TARGET_REF|TARGET_SYM;
 	else
@@ -1690,15 +1712,13 @@ parsefile(char *const *argv, const char *cwd, const char *root, const char *dbpa
 	}
 }
 /**
- * @fn int search(const char *pattern, const char *root, const char *cwd, const char *dbpath, int db)
- *
  * search: search specified function 
  *
  *	@param[in]	pattern		search pattern
  *	@param[in]	root		root of source tree
  *	@param[in]	cwd		current directory
  *	@param[in]	dbpath		database directory
- *	@param[in]	db		#GTAGS,#GRTAGS,#GSYMS
+ *	@param[in]	db		GTAGS,GRTAGS,GSYMS
  *	@return			count of output lines
  */
 int
@@ -1750,7 +1770,7 @@ search(const char *pattern, const char *root, const char *cwd, const char *dbpat
  *	@param[in]	cwd		current directory
  *	@param[in]	root		root of source tree
  *	@param[in]	dbpath		database directory
- *	@param[in]	db		#GTAGS,#GRTAGS,#GSYMS
+ *	@param[in]	db		GTAGS,GRTAGS,GSYMS
  */
 void
 tagsearch(const char *pattern, const char *cwd, const char *root, const char *dbpath, int db)
@@ -1788,6 +1808,7 @@ tagsearch(const char *pattern, const char *cwd, const char *root, const char *db
 		char *libdir, *nextp = NULL;
 
 		strbuf_puts(sb, getenv("GTAGSLIBPATH"));
+		back2slash(sb);
 		/*
 		 * search for each tree in the library path.
 		 */
@@ -1796,7 +1817,7 @@ tagsearch(const char *pattern, const char *cwd, const char *root, const char *db
 				*nextp++ = 0;
 			if (!gtagsexist(libdir, libdbpath, sizeof(libdbpath), 0))
 				continue;
-			if (!strcmp(dbpath, libdbpath))
+			if (!STRCMP(dbpath, libdbpath))
 				continue;
 			if (!test("f", makepath(libdbpath, dbname(db), NULL)))
 				continue;
@@ -1820,11 +1841,11 @@ tagsearch(const char *pattern, const char *cwd, const char *root, const char *db
 		fputs(".\n", stderr);
 	}
 }
-/**
- * encode: string copy with converting blank chars into @CODE{\%ff} format.
+/*
+ * encode: string copy with converting blank chars into %ff format.
  *
  *	@param[out]	to	result
- *	@param[in]	size	size of @a to buffer
+ *	@param[in]	size	size of to buffer
  *	@param[in]	from	string
  */
 void
