@@ -56,9 +56,15 @@
 #include "parser.h"
 #include "const.h"
 
-/**
- @file
- @NAME{gtags} - create tag files for @NAME{global}.
+/*
+ * enable [set] globbing, if available
+ */
+#ifdef __CRT_GLOB_BRACKET_GROUPS__
+int _CRT_glob = __CRT_GLOB_USE_MINGW__ | __CRT_GLOB_BRACKET_GROUPS__;
+#endif
+
+/*
+ gtags - create tag files for global.
 */
 
 static void usage(void);
@@ -141,6 +147,7 @@ static struct option const long_options[] = {
 #define OPT_PATH		131
 #define OPT_SINGLE_UPDATE	132
 #define OPT_ACCEPT_DOTFILES	133
+#define OPT_SKIP_UNREADABLE	134
 	/* flag value */
 	{"accept-dotfiles", no_argument, NULL, OPT_ACCEPT_DOTFILES},
 	{"debug", no_argument, &debug, 1},
@@ -148,6 +155,7 @@ static struct option const long_options[] = {
 #ifdef USE_SQLITE3
 	{"sqlite3", no_argument, &use_sqlite3, 1},
 #endif
+	{"skip-unreadable", no_argument, NULL, OPT_SKIP_UNREADABLE},
 	{"statistics", no_argument, &statistics, STATISTICS_STYLE_TABLE},
 	{"version", no_argument, &show_version, 1},
 	{"help", no_argument, &show_help, 1},
@@ -235,6 +243,9 @@ main(int argc, char **argv)
 		case OPT_ACCEPT_DOTFILES:
 			set_accept_dotfiles();
 			break;
+		case OPT_SKIP_UNREADABLE:
+			set_skip_unreadable();
+			break;
 		case 'c':
 			cflag++;
 			break;
@@ -265,6 +276,7 @@ main(int argc, char **argv)
 			break;
 		case 'w':
 			wflag++;
+			set_langmap_wflag();
 			break;
 		case 'v':
 			vflag++;
@@ -427,16 +439,32 @@ main(int argc, char **argv)
 	}
 	if (!test("d", dbpath))
 		die("directory '%s' not found.", dbpath);
-	if (vflag)
+	/*
+	 * Start processing.
+	 */
+	if (vflag) {
+		const char *config_path = getconfigpath();
+		const char *config_label = getconfiglabel();
+
 		fprintf(stderr, "[%s] Gtags started.\n", now());
+		if (config_path)
+			fprintf(stderr, " Using configuration file '%s'.\n", config_path);
+		else {
+			fprintf(stderr, " Using default configuration.\n");
+			if (getenv("GTAGSLABEL"))
+				fprintf(stderr, " GTAGSLABEL(--gtagslabel) ignored since configuration file not found.\n");
+		}
+		if (config_label)
+			fprintf(stderr, " Using configuration label '%s'.\n", config_label);
+		if (file_list)
+			fprintf(stderr, " Using '%s' as a file list.\n", file_list);
+	}
 	/*
 	 * initialize parser.
 	 */
 	if (vflag && gtags_parser)
 		fprintf(stderr, " Using plug-in parser.\n");
 	parser_init(langmap, gtags_parser);
-	if (vflag && file_list)
-		fprintf(stderr, " Using '%s' as a file list.\n", file_list);
 	/*
 	 * Start statistics.
 	 */
@@ -741,7 +769,7 @@ exit:
 	return updated;
 }
 /**
- * @fn static void put_syms(int type, const char *tag, int lno, const char *path, const char *line_image, void *arg)
+ * static void put_syms(int type, const char *tag, int lno, const char *path, const char *line_image, void *arg)
  *
  * callback functions for built-in parser
  */
@@ -798,7 +826,7 @@ put_syms(int type, const char *tag, int lno, const char *path, const char *line_
  *	@param[in]	dbpath		directory in which tag file exist
  *	@param[in]	root		root directory of source tree
  *	@param[in]	deleteset	bit array of fid of deleted or modified files 
- *	@param[in]	addlist		@CODE{\\0} separated list of added or modified files
+ *	@param[in]	addlist		'\0' separated list of added or modified files
  */
 void
 updatetags(const char *dbpath, const char *root, IDSET *deleteset, STRBUF *addlist)
@@ -860,6 +888,8 @@ updatetags(const char *dbpath, const char *root, IDSET *deleteset, STRBUF *addli
 		flags |= PARSER_WARNING;
 	if (explain)
 		flags |= PARSER_EXPLAIN;
+	if (getenv("GTAGSFORCEENDBLOCK"))
+		flags |= PARSER_END_BLOCK;
 	/*
 	 * Add tags to GTAGS and GRTAGS.
 	 */
@@ -921,6 +951,8 @@ createtags(const char *dbpath, const char *root)
 		flags |= PARSER_WARNING;
 	if (explain)
 		flags |= PARSER_EXPLAIN;
+	if (getenv("GTAGSFORCEENDBLOCK"))
+		flags |= PARSER_END_BLOCK;
 	/*
 	 * Add tags to GTAGS and GRTAGS.
 	 */
