@@ -48,14 +48,14 @@ static int enumerator_list(const struct parser_param *);
 
 #define MAXPIFSTACK	100
 
-/**
- * @name #ifdef stack.
+/*
+ * #ifdef stack.
  */
 
 static struct {
-	short start;		/**< level when @CODE{\#if} block started */
-	short end;		/**< level when @CODE{\#if} block end */
-	short if0only;		/**< @CODE{\#if 0} or notdef only */
+	short start;		/**< level when '#if' block started */
+	short end;		/**< level when '#if' block end */
+	short if0only;		/**< '#if 0' or notdef only */
 } pifstack[MAXPIFSTACK], *cur;
 static int piflevel;		/**< condition macro level */
 static int level;		/**< brace level */
@@ -129,6 +129,7 @@ Cpp(const struct parser_param *param)
 			}
 			break;
 		case CPP_USING:
+			crflag = 0;
 			/*
 			 * using namespace name;
 			 * using ...;
@@ -141,8 +142,27 @@ Cpp(const struct parser_param *param)
 						warning("missing namespace name. [+%d %s].", lineno, curfile);
 					pushbacktoken();
 				}
-			} else
+			} else if (c  == SYMBOL) {
+				char savetok[MAXTOKEN], *saveline;
+				int savelineno = lineno;
+
+				strlimcpy(savetok, token, sizeof(savetok));
+				strbuf_reset(sb);
+				strbuf_puts(sb, sp);
+				saveline = strbuf_value(sb);
+				if ((c = nexttoken(interested, cpp_reserved_word)) == '=') {
+					PUT(PARSER_DEF, savetok, savelineno, saveline);
+				} else {
+					PUT(PARSER_REF_SYM, savetok, savelineno, saveline);
+					while (c == SYMBOL) {
+						PUT(PARSER_REF_SYM, token, lineno, sp);
+						c = nexttoken(interested, cpp_reserved_word);
+					}
+				}
+			} else {
 				pushbacktoken();
+			}
+			crflag = 1;
 			break;
 		case CPP_NAMESPACE:
 			crflag = 0;
@@ -426,6 +446,7 @@ Cpp(const struct parser_param *param)
 				char savetok[MAXTOKEN];
 				int savelineno = 0;
 				int typedef_savelevel = level;
+				int templates = 0;
 
 				savetok[0] = 0;
 
@@ -502,7 +523,7 @@ Cpp(const struct parser_param *param)
 					PUT(PARSER_REF_SYM, token, lineno, sp);
 				}
 				savetok[0] = 0;
-				while ((c = nexttoken("(),;", cpp_reserved_word)) != EOF) {
+				while ((c = nexttoken("()<>,;", cpp_reserved_word)) != EOF) {
 					switch (c) {
 					case SHARP_IFDEF:
 					case SHARP_IFNDEF:
@@ -519,6 +540,10 @@ Cpp(const struct parser_param *param)
 						level++;
 					else if (c == ')')
 						level--;
+					else if (c == '<')
+						templates++;
+					else if (c == '>')
+						templates--;
 					else if (c == SYMBOL) {
 						if (level > typedef_savelevel) {
 							PUT(PARSER_REF_SYM, token, lineno, sp);
@@ -533,7 +558,7 @@ Cpp(const struct parser_param *param)
 						}
 					} else if (c == ',' || c == ';') {
 						if (savetok[0]) {
-							PUT(PARSER_DEF, savetok, lineno, sp);
+							PUT(templates ? PARSER_REF_SYM : PARSER_DEF, savetok, lineno, sp);
 							savetok[0] = 0;
 						}
 					}
@@ -565,7 +590,7 @@ Cpp(const struct parser_param *param)
 	closetoken();
 }
 /**
- * process_attribute: skip attributes in @CODE{__attribute__((...))}.
+ * process_attribute: skip attributes in '__attribute__((...))'.
  */
 static void
 process_attribute(const struct parser_param *param)
@@ -643,6 +668,9 @@ function_definition(const struct parser_param *param)
 		case CPP___ATTRIBUTE__:
 			process_attribute(param);
 			continue;
+		case SHARP_DEFINE:
+			pushbacktoken();
+			return 0;
 		default:
 			break;
 		}
@@ -729,7 +757,7 @@ condition_macro(const struct parser_param *param, int cc)
 }
 
 /**
- * enumerator_list: process @CODE{"symbol (= expression), ... \}"}
+ * enumerator_list: process "symbol (= expression), ... "}
  */
 static int
 enumerator_list(const struct parser_param *param)
