@@ -144,18 +144,16 @@ compare_neartags(const void *v1, const void *v2)
 	return e1->lineno - e2->lineno;
 }
 /**
- * @fn static const char *seekto(const char *string, int n)
+ * static const char *seekto(const char *string, int n)
  * seekto: seek to the specified item of tag record.
  *
- * @par Usage:
- * @code
+ * Usage:
  *           0         1          2
  * tagline = <file id> <tag name> <line number>
  *
  * <file id>     = seekto(tagline, SEEKTO_FILEID);
  * <tag name>    = seekto(tagline, SEEKTO_TAGNAME);
  * <line number> = seekto(tagline, SEEKTO_LINENO);
- * @endcode
  */
 #define SEEKTO_FILEID	0
 #define SEEKTO_TAGNAME	1
@@ -173,69 +171,52 @@ seekto(const char *string, int n)
 	}
 	return p;
 }
-/**
+/*
  * Tag format
  *
- * [@EMPH{Specification of format version 6}]
+ * [Specification of format version 6]
  * 
- * @par Standard format:
+ * Standard format:
  *
- *	This format is the default format of #GTAGS.
+ *	This format is the default format of GTAGS.
  * 
- * @par
- * @code{.txt}
  *         <file id> <tag name> <line number> <line image>
- * @endcode
  * 
- * @par
  *                 * Separator is single blank.
  * 
- * @par
- * @code{.txt}
  *         [example]
  *         +------------------------------------
  *         |110 func 10 int func(int a)
  *         |110 func 30 func(int a1, int a2)
- * @endcode
  * 
- * @par
- *         Line image might be compressed (#GTAGS_COMPRESS). <br>
- *         Tag name might be compressed (#GTAGS_COMPNAME).
+ *         Line image might be compressed (GTAGS_COMPRESS).
+ *         Tag name might be compressed (GTAGS_COMPNAME).
  *
- * @par Compact format:
+ * Compact format:
  * 
- * @par
- *	This format is the default format of #GRTAGS. <br>
- *	It is used for #GTAGS with the @OPTION{-c} option.
+ *	This format is the default format of GRTAGS.
+ *	It is used for GTAGS with the -c option.
  *
- * @par
- * @code{.txt}
  *         <file id> <tag name> <line number>,...
- * @endcode
  * 
- * @par
  *                 * Separator is single blank.
  * 
- * @par
- * @code{.txt}
  *         [example]
  *         +------------------------------------
  *         |110 func 10,30
- * @endcode
  * 
- * @par
- *         Line numbers are sorted in a line. <br>
+ *         Line numbers are sorted in a line.
  *	   Each line number might be expressed as difference from the previous
- *	   line number except for the head (#GTAGS_COMPLINE). <br>
- *           ex: 10,3,2 means '10 13 15'. <br>
- *	   In addition,successive line numbers are expressed as a range. <br>
+ *	   line number except for the head (GTAGS_COMPLINE).
+ *           ex: 10,3,2 means '10 13 15'.
+ *	   In addition,successive line numbers are expressed as a range.
  *           ex: 10-3 means '10 11 12 13'.
  *
- * @par [Description]
+ * [Description]
  * 
- * - Standard format is applied to #GTAGS, and compact format is applied
- *     to #GRTAGS by default.
- * - #GSYMS is not used any longer. It is virtually included by GRTAGS.
+ * - Standard format is applied to GTAGS, and compact format is applied
+ *     to GRTAGS by default.
+ * - GSYMS is not used any longer. It is virtually included by GRTAGS.
  * - Above two formats are same to the first line number. So, we can use
  *     common function to sort them.
  * - Separator is single blank.
@@ -247,26 +228,24 @@ seekto(const char *string, int n)
  *     We can access file id without string processing.
  *     This is advantageous for deleting tag record when incremental updating.
  * 
- * @par [Concept of format version]
+ * [Concept of format version]
  *
- * Since @NAME{GLOBAL}'s tag files are machine independent, they can be distributed
- * apart from @NAME{GLOBAL} itself. For example, if some network file system available,
+ * Since GLOBAL's tag files are machine independent, they can be distributed
+ * apart from GLOBAL itself. For example, if some network file system available,
  * client may execute global using server's tag files. In this case, both
- * @NAME{GLOBAL} are not necessarily the same version. So, we should assume that
- * older version of @NAME{GLOBAL} might access the tag files which generated
- * by new @NAME{GLOBAL}. To deal in such case, we decided to buried a version number
- * to both @XREF{global,1} and tag files. The conclete procedure is like follows:
+ * GLOBAL are not necessarily the same version. So, we should assume that
+ * older version of GLOBAL might access the tag files which generated
+ * by new GLOBAL. To deal in such case, we decided to buried a version number
+ * to both global(1) and tag files. The conclete procedure is like follows:
  *
- * @par
- * -# @XREF{gtags,1} bury the version number in tag files. <br>
- * -# @XREF{global,1} pick up the version number from a tag file. If the number
+ *  1. gtags(1) bury the version number in tag files.
+ *  2. global(1) pick up the version number from a tag file. If the number
  *      is larger than its acceptable version number then global give up work
- *      any more and display error message. <br>
- * -# If version number is not found then it assumes version 1.
+ *      any more and display error message.
+ *  3. If version number is not found then it assumes version 1.
  *
- * @par [History of format version]
+ * [History of format version]
  *
- @verbatim
   GLOBAL-1.0 - 1.8     no idea about format version.
   GLOBAL-1.9 - 2.24    understand format version.
                        support format version 1 (default).
@@ -281,33 +260,30 @@ seekto(const char *string, int n)
                        if (format > 5 || format < 4) then print error message.
   GLOBAL-5.9 -		support only format version 6
                        if (format > 6 || format < 6) then print error message.
- @endverbatim
  *
- * In @NAME{GLOBAL-5.0}, we threw away the compatibility with the past formats.
+ * In GLOBAL-5.0, we threw away the compatibility with the past formats.
  * Though we could continue the support for older formats, it seemed
  * not to be worthy. Because keeping maintaining the all formats hinders
  * new optimization and the function addition in the future.
  * Instead, the following error messages are displayed in a wrong usage.
- * @code{.sh}
+ *
  *       [older global and new tag file]
  *       $ global -x main
  *       GTAGS seems new format. Please install the latest GLOBAL.
  *       [new global and older tag file]
  *       $ global -x main
  *       GTAGS seems older format. Please remake tag files.
- * @endcode
  */
 static int new_format_version = 6;	/**< new format version */
 static int upper_bound_version = 6;	/**< acceptable format version (upper bound) */
 static int lower_bound_version = 6;	/**< acceptable format version (lower bound) */
 static const char *const tagslist[] = {"GPATH", "GTAGS", "GRTAGS", "GSYMS"};
 /**
- * Virtual #GRTAGS, #GSYMS processing:
+ * Virtual GRTAGS, GSYMS processing:
  *
- * We use a real @NAME{GRTAGS} as virtual @NAME{GRTAGS} and @NAME{GSYMS}.
- * In fact, @NAME{GSYMS} tag file doesn't exist.
+ * We use a real GRTAGS as virtual GRTAGS and GSYMS.
+ * In fact, GSYMS tag file doesn't exist.
  *
- * @code{.txt}
  * Real tag file	virtual tag file
  * --------------------------------------
  * GTAGS =============> GTAGS
@@ -315,7 +291,6 @@ static const char *const tagslist[] = {"GPATH", "GTAGS", "GRTAGS", "GSYMS"};
  * GRTAGS ============> GRTAGS + GSYMS
  *            +=======> GRTAGS	tags which is defined in GTAGS
  *            +=======> GSYMS	tags which is not defined in GTAGS
- * @endcode
  */
 #define VIRTUAL_GRTAGS_GSYMS_PROCESSING(gtop) 						\
 	if (gtop->db == GRTAGS || gtop->db == GSYMS) {					\
@@ -324,13 +299,13 @@ static const char *const tagslist[] = {"GPATH", "GTAGS", "GRTAGS", "GSYMS"};
 			continue;							\
 	}
 /**
- * is_defined_in_GTAGS: whether or not the name is defined in #GTAGS.
+ * is_defined_in_GTAGS: whether or not the name is defined in GTAGS.
  *
  *	@param[in]	gtop
  *	@param[in]	name	tag name
  *	@return		0: not defined, 1: defined
  *
- * @note It is assumed that the input stream is sorted by the tag name.
+ * [Note] It is assumed that the input stream is sorted by the tag name.
  */
 static int
 is_defined_in_GTAGS(GTOP *gtop, const char *name)
@@ -346,7 +321,7 @@ is_defined_in_GTAGS(GTOP *gtop, const char *name)
 /**
  * dbname: return db name
  *
- *	@param[in]	db	0: #GPATH, 1: #GTAGS, 2: #GRTAGS, 3: #GSYMS
+ *	@param[in]	db	0: GPATH, 1: GTAGS, 2: GRTAGS, 3: GSYMS
  *	@return		dbname
  */
 const char *
@@ -362,14 +337,14 @@ dbname(int db)
  *
  *	@param[in]	dbpath	dbpath directory
  *	@param[in]	root	root directory (needed when compact format)
- *	@param[in]	db	#GTAGS, #GRTAGS, #GSYMS
- *	@param[in]	mode	#GTAGS_READ: read only <br>
- *			#GTAGS_CREATE: create tag <br>
- *			#GTAGS_MODIFY: modify tag
- *	@param[in]	flags	#GTAGS_COMPACT: compact format
- *	@return		#GTOP structure
+ *	@param[in]	db	GTAGS, GRTAGS, GSYMS
+ *	@param[in]	mode	GTAGS_READ: read only,
+ *			GTAGS_CREATE: create tag,
+ *			GTAGS_MODIFY: modify tag
+ *	@param[in]	flags	GTAGS_COMPACT: compact format
+ *	@return		GTOP structure
  *
- * @note when error occurred, @NAME{gtags_open()} doesn't return.
+ * [Note] when error occurred, gtags_open() doesn't return.
  */
 GTOP *
 gtags_open(const char *dbpath, const char *root, int db, int mode, int flags)
@@ -515,7 +490,7 @@ gtags_open(const char *dbpath, const char *root, int db, int mode, int flags)
 /**
  * gtags_put_using: put tag record with packing.
  *
- *	@param[in]	gtop	descripter of #GTOP
+ *	@param[in]	gtop	descripter of GTOP
  *	@param[in]	tag	tag name
  *	@param[in]	lno	line number
  *	@param[in]	fid	file id
@@ -577,7 +552,7 @@ gtags_put_using(GTOP *gtop, const char *tag, int lno, const char *fid, const cha
 /**
  * gtags_flush: Flush the pool for compact format.
  *
- *	@param[in]	gtop	descripter of #GTOP
+ *	@param[in]	gtop	descripter of GTOP
  *	@param[in]	fid	file id
  */
 void
@@ -591,7 +566,7 @@ gtags_flush(GTOP *gtop, const char *fid)
 /**
  * gtags_delete: delete records belong to set of fid.
  *
- *	@param[in]	gtop	#GTOP structure
+ *	@param[in]	gtop	GTOP structure
  *	@param[in]	deleteset bit array of fid
  */
 void
@@ -599,11 +574,11 @@ gtags_delete(GTOP *gtop, IDSET *deleteset)
 {
 	const char *tagline;
 	int fid;
-	long id;
 
 #ifdef USE_SQLITE3
 	if (gtop->dbop->openflags & DBOP_SQLITE3) {
 		STRBUF *where = strbuf_open(0);
+		long id;
 		strbuf_puts(where, "(");
 		for (id = idset_first(deleteset); id != END_OF_ID; id = idset_next(deleteset)) {
 			strbuf_puts(where, "'");
@@ -680,10 +655,10 @@ get_prefix(const char *pattern, int flags)
 /**
  * gtags_restart: restart dbop iterator using lower case prefix.
  *
- *	@param[in]	gtop	#GTOP structure
+ *	@param[in]	gtop	GTOP structure
  *	@return		prepared or not
- *			#0:	cannot continue
- *			#1:	can continue
+ *			0:	cannot continue
+ *			1:	can continue
  */
 static int
 gtags_restart(GTOP *gtop)
@@ -709,18 +684,18 @@ gtags_restart(GTOP *gtop)
 /**
  * gtags_first: return first record
  *
- *	@param[in]	gtop	#GTOP structure
- *	@param[in]	pattern	tag name <br>
+ *	@param[in]	gtop	GTOP structure
+ *	@param[in]	pattern	tag name,
  *		- may be regular expression
- *		- may be @VAR{NULL}
- *	@param[in]	flags	#GTOP_PREFIX:	prefix read <br>
- *			#GTOP_KEY:	read key only <br>
- *			#GTOP_PATH:	read path only <br>
- *			#GTOP_NOREGEX:	don't use regular expression. <br>
- *			#GTOP_IGNORECASE:	ignore case distinction. <br>
- *			#GTOP_BASICREGEX:	use basic regular expression. <br>
- *			#GTOP_NEARSORT:		use 'Nearness sort'. <br>
- *			#GTOP_NOSORT:		don't sort
+ *		- may be NULL
+ *	@param[in]	flags	GTOP_PREFIX:	prefix read,
+ *			GTOP_KEY:	read key only,
+ *			GTOP_PATH:	read path only,
+ *			GTOP_NOREGEX:	don't use regular expression.
+ *			GTOP_IGNORECASE:	ignore case distinction.
+ *			GTOP_BASICREGEX:	use basic regular expression.
+ *			GTOP_NEARSORT:		use 'Nearness sort'.
+ *			GTOP_NOSORT:		don't sort
  *
  *			By default, sort is done by alphabetical order.
  *	@return		record
@@ -936,9 +911,9 @@ again2:
 /**
  * gtags_next: return next record.
  *
- *	@param[in]	gtop	#GTOP structure
+ *	@param[in]	gtop	GTOP structure
  *	@return		record
- *			@VAR{NULL} end of tag
+ *			NULL end of tag
  */
 GTP *
 gtags_next(GTOP *gtop)
@@ -997,7 +972,7 @@ gtags_show_statistics(GTOP *gtop)
 /**
  * gtags_close: close tag file
  *
- *	@param[in]	gtop	#GTOP structure
+ *	@param[in]	gtop	GTOP structure
  */
 void
 gtags_close(GTOP *gtop)
@@ -1023,7 +998,7 @@ gtags_close(GTOP *gtop)
 /**
  * flush_pool: flush and write the pool as compact format.
  *
- *	@param[in]	gtop	descripter of #GTOP
+ *	@param[in]	gtop	descripter of GTOP
  *	@param[in]	s_fid
  */
 static void
@@ -1153,14 +1128,14 @@ flush_pool(GTOP *gtop, const char *s_fid)
 /**
  * Read a tag segment with sorting.
  *
- *	@param[in]	gtop	#GTOP structure <br>
- *		Output:	@CODE{gtop->gtp_array}		segment table <br>
- *		Output:	@CODE{gtop->gtp_count}		segment table size <br>
- *		Output:	@CODE{gtop->gtp_index}		segment table index (initial value = 0) <br>
- *		Output:	@CODE{gtop->cur_tagname}	current tag name
+ *	@param[in]	gtop	GTOP structure
+ *		Output:	gtop->gtp_array		segment table
+ *		Output:	gtop->gtp_count		segment table size
+ *		Output:	gtop->gtp_index		segment table index (initial value = 0)
+ *		Output:	gtop->cur_tagname	current tag name
  *
- * A segment is a set of tag records which have same tag name. <br>
- * This function read a segment from tag file, sort it and put it on segment table. <br>
+ * A segment is a set of tag records which have same tag name.
+ * This function read a segment from tag file, sort it and put it on segment table.
  * This function can treat both of standard format and compact format.
  *
  * Sorting is done by three keys.
