@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004, 2011 Tama Communications Corporation
+ * Copyright (c) 2004, 2011, 2015 Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -26,7 +26,9 @@
 #define DEFAULTSKIP     "HTML/,HTML.pub/,tags,TAGS,ID,y.tab.c,y.tab.h,gtags.files,cscope.files,cscope.out,cscope.po.out,cscope.in.out,SCCS/,RCS/,CVS/,CVSROOT/,{arch}/,autom4te.cache/,*.orig,*.rej,*.bak,*~,#*#,*.swp,*.tmp,*_flymake.*,*_flymake"
 #define DEFAULTINCLUDEFILESUFFIXES "h,hh,hxx,hpp,H,inc.php"
 
+void set_langmap_wflag(void);
 void setup_langmap(const char *);
+const char *trim_langmap(const char *);
 const char *decide_lang(const char *);
 void make_suffixes(const char *, STRBUF *);
 
