@@ -38,15 +38,13 @@
 #ifndef isblank
 #define isblank(c)	((c) == ' ' || (c) == '\t')
 #endif
-/**
- @file
+/*
 
 String buffer: usage and memory status
 
-					[xxx]: string buffer <br>
+					[xxx]: string buffer
 					'v': current pointer
 
-@code
 Function call                           Memory status
 ----------------------------------------------------------
                                         (not exist)
@@ -76,13 +74,12 @@ char *s = strbuf_fgets(sb, fp, 0)       [root:*:0:0:Charlie &:/root:/bin/csh\0]
 fclose(fp)				s == "root:*:0:0:Charlie &:/root:/bin/csh"
 
 strbuf_close(sb);                       (not exist)
-@endcode
 */
 
 /**
  * __strbuf_expandbuf: expand buffer so that afford to the length data at least.
  *
- *	@param[in]	sb	#STRBUF structure
+ *	@param[in]	sb	STRBUF structure
  *	@param[in]	length	required room
  */
 void
@@ -102,9 +99,9 @@ __strbuf_expandbuf(STRBUF *sb, int length)
 /**
  * strbuf_open: open string buffer.
  *
- *	@param[in]	init	initial buffer size <br>
- *			if 0 (zero) is specified then use default value (#INITIALSIZE).
- *	@return	sb	#STRBUF structure
+ *	@param[in]	init	initial buffer size
+ *			if 0 (zero) is specified then use default value (INITIALSIZE).
+ *	@return	sb	STRBUF structure
  */
 STRBUF *
 strbuf_open(int init)
@@ -134,7 +131,7 @@ strbuf_reset(STRBUF *sb)
  *	@param[in]	sb	statically defined string buffer
  *
  * This function is used for the initializing of static string buffer.
- * For the detail, see STATIC_STRBUF(sb) macro in @FILE{strbuf.h}.
+ * For the detail, see STATIC_STRBUF(sb) macro in "strbuf.h".
  */
 void
 strbuf_clear(STRBUF *sb)
@@ -153,7 +150,7 @@ strbuf_clear(STRBUF *sb)
 /**
  * strbuf_nputs: Put string with length
  *
- *	@param[in]	sb	string buffer
+ *	@param[in,out]	sb	string buffer
  *	@param[in]	s	string
  *	@param[in]	len	length of string
  */
@@ -168,13 +165,13 @@ strbuf_nputs(STRBUF *sb, const char *s, int len)
 	}
 }
 /**
- * strbuf_nputc: Put a character, @a len (number) times
+ * strbuf_nputc: Put a character, len (number) times
  *
- *	@param[in]	sb	string buffer
+ *	@param[in,out]	sb	string buffer
  *	@param[in]	c	character
- *	@param[in]	len	number of times to put @a c
+ *	@param[in]	len	number of times to put c
  *
- *	@see strbuf_putc()
+ *	See strbuf_putc()
  */
 void
 strbuf_nputc(STRBUF *sb, int c, int len)
@@ -189,7 +186,7 @@ strbuf_nputc(STRBUF *sb, int c, int len)
 /**
  * strbuf_puts: Put string
  *
- *	@param[in]	sb	string buffer
+ *	@param[in,out]	sb	string buffer
  *	@param[in]	s	string
  */
 void
@@ -204,10 +201,9 @@ strbuf_puts(STRBUF *sb, const char *s)
 /**
  * strbuf_puts_withterm: Put string until the terminator
  *
- *	@param[in]	sb	string buffer
+ *	@param[in,out]	sb	string buffer
  *	@param[in]	s	string
  *	@param[in]	c	terminator
- *	@return		pointer to the terminator
  */
 void
 strbuf_puts_withterm(STRBUF *sb, const char *s, int c)
@@ -221,7 +217,7 @@ strbuf_puts_withterm(STRBUF *sb, const char *s, int c)
 /**
  * strbuf_puts_nl: Put string with a new line
  *
- *	@param[in]	sb	string buffer
+ *	@param[in,out]	sb	string buffer
  *	@param[in]	s	string
  */
 void
@@ -239,7 +235,7 @@ strbuf_puts_nl(STRBUF *sb, const char *s)
 /**
  * strbuf_putn: put digit string at the last of buffer.
  *
- *	@param[in]	sb	#STRBUF structure
+ *	@param[in,out]	sb	STRBUF structure
  *	@param[in]	n	number
  */
 void
@@ -264,7 +260,7 @@ strbuf_putn(STRBUF *sb, int n)
 /**
  * strbuf_putn64: put digit string at the last of buffer.
  *
- *	@param[in]	sb	#STRBUF structure
+ *	@param[in,out]	sb	STRBUF structure
  *	@param[in]	n	number
  */
 void
@@ -289,7 +285,7 @@ strbuf_putn64(STRBUF *sb, long long n)
 /**
  * strbuf_unputc: remove specified char from the last of buffer
  *
- *	@param[in]	sb	#STRBUF structure
+ *	@param[in,out]	sb	STRBUF structure
  *	@param[in]	c	character
  *	@return		0: do nothing, 1: removed
  */
@@ -305,7 +301,7 @@ strbuf_unputc(STRBUF *sb, int c)
 /**
  * strbuf_value: return the content of string buffer.
  *
- *	@param[in]	sb	#STRBUF structure
+ *	@param[in]	sb	STRBUF structure
  *	@return		string
  */
 char *
@@ -317,7 +313,7 @@ strbuf_value(STRBUF *sb)
 /**
  * strbuf_trim: trim following blanks.
  *
- *	@param[in]	sb	#STRBUF structure
+ *	@param[in,out]	sb	STRBUF structure
  */
 void
 strbuf_trim(STRBUF *sb)
@@ -328,20 +324,20 @@ strbuf_trim(STRBUF *sb)
 		*--p = 0;
 	sb->curp = p;
 }
-/**
+/*
  * strbuf_fgets: read whole record into string buffer
  *
- *	@param[out]	sb	string buffer
+ *	@param[in,out]	sb	string buffer
  *	@param[in]	ip	input stream
- *	@param[in]	flags	flags <br>
- *			#STRBUF_NOCRLF:	remove last @CODE{'\\n'} and/or @CODE{'\\r'} if exist. <br>
- *			#STRBUF_APPEND:	append next record to existing data <br>
- *			#STRBUF_SHARPSKIP: skip lines which start with @CODE{'\#'}
- *	@return		record buffer (@VAR{NULL} at end of file)
+ *	@param[in]	flags	flags
+ *			STRBUF_NOCRLF:	remove last '\n' and/or '\r' if exist.
+ *			STRBUF_APPEND:	append next record to existing data
+ *			STRBUF_SHARPSKIP: skip lines which start with '#'
+ *	@return		record buffer (NULL at end of file)
  *
- * Returned buffer has whole record. <br>
- * The buffer end with @CODE{'\\0'}. If #STRBUF_NOCRLF is set then buffer doesn't
- * include @CODE{'\\r'} and @CODE{'\\n'}.
+ * Returned buffer has whole record.
+ * The buffer end with '\0'. If STRBUF_NOCRLF is set then buffer doesn't
+ * include '\r' and '\n'.
  */
 char *
 strbuf_fgets(STRBUF *sb, FILE *ip, int flags)
@@ -376,13 +372,13 @@ strbuf_fgets(STRBUF *sb, FILE *ip, int flags)
 	}
 	return sb->sbuf;
 }
-/**
- * strbuf_sprintf: do @NAME{sprintf} into string buffer.
+/*
+ * strbuf_sprintf: do sprintf into string buffer.
  *
- *	@param[in]	sb	#STRBUF structure
- *	@param[in]	s	similar to @NAME{sprintf()} <br>
- *			Currently the following format is supported. <br>
- *			@CODE{\%s, \%d, \%\<number\>d, \%\<number\>s, \%-\<number\>d, \%-\<number\>s}
+ *	@param[in,out]	sb	STRBUF structure
+ *	@param[in]	s	similar to sprintf()
+ *			Currently the following format is supported.
+ *			%s, %d, %<number>d, %<number>s, %-<number>d, %-<number>s
  */
 void
 strbuf_sprintf(STRBUF *sb, const char *s, ...)
@@ -393,14 +389,14 @@ strbuf_sprintf(STRBUF *sb, const char *s, ...)
 	strbuf_vsprintf(sb, s, ap);
 	va_end(ap);
 }
-/**
- * strbuf_vsprintf: do @NAME{vsprintf} into string buffer.
+/*
+ * strbuf_vsprintf: do vsprintf into string buffer.
  *
- *	@param[in]	sb	#STRBUF structure
- *	@param[in]	s	similar to @NAME{vsprintf()} <br>
- *			Currently the following format is supported. <br>
- *			@CODE{\%s, \%d, \%\<number\>d, \%\<number\>s, \%-\<number\>d, \%-\<number\>s}
- *	@param[in]	ap	 <br>
+ *	@param[in,out]	sb	STRBUF structure
+ *	@param[in]	s	similar to vsprintf()
+ *			Currently the following format is supported.
+ *			%s, %d, %<number>d, %<number>s, %-<number>d, %-<number>s
+ *	@param[in]	ap 
  */
 void
 strbuf_vsprintf(STRBUF *sb, const char *s, va_list ap)
@@ -467,7 +463,7 @@ strbuf_vsprintf(STRBUF *sb, const char *s, va_list ap)
 /**
  * strbuf_close: close string buffer.
  *
- *	@param[in]	sb	#STRBUF structure
+ *	@param[in]	sb	STRBUF structure
  */
 void
 strbuf_close(STRBUF *sb)
@@ -478,19 +474,17 @@ strbuf_close(STRBUF *sb)
 	(void)free(sb);
 }
 /**
- * @fn STRBUF *strbuf_open_tempbuf(void)
+ * STRBUF *strbuf_open_tempbuf(void)
  *
  * Temporary string buffer for general purpose.
  *
- * @par Usage:
+ * Usage:
  *
- * @code
  *	STRBUF *sbt = strbuf_open_tempbuf();
  *	....
  *	strbuf_puts(sbtemp, "xxx");
  *	...
  *	strbuf_release_tempbuf(sbt);
- * @endcode
  *
  */
 static int used = 0;
@@ -505,6 +499,10 @@ strbuf_open_tempbuf(void)
 	strbuf_clear(sb);
 	return sb;
 }
+
+/**
+ * [Note] this function is for use with strbuf_open_tempbuf() only.
+ */
 void
 strbuf_release_tempbuf(STRBUF *sb)
 {
